@@ -24,7 +24,6 @@ from .models import WordProgress, VowelType
 from .errors import HyphenatorError
 from .util import CONSONANTS, is_vowel
 
-
 CONSONANTS_BAR_Y = CONSONANTS - set("y")
 
 
@@ -45,7 +44,7 @@ def hyphenate(word: str) -> WordProgress:
 
         num_syl = len(word.syllables)
         if word.stress_found and word.stressed is None:
-            word.stressed = num_syl
+            word.stressed = num_syl - 1
 
     # If the word does not have a graphical accent, then find the stressed
     # syllable according to the Spanish rules
@@ -53,16 +52,16 @@ def hyphenate(word: str) -> WordProgress:
         num_syl = len(word.syllables)
         # If the word has only one syllable, that's the one!
         if num_syl == 1:
-            word.stressed = num_syl
+            word.stressed = num_syl - 1
         else:
             end = word[-1]
             prev = word[-2]
             # Ends in vowel (including y) or n or s
             if is_vowel(end) or end in 'yns' and is_vowel(prev):
-                word.stressed = num_syl - 1
+                word.stressed = num_syl - 2
             else:
-                word.stressed = num_syl
-    word.syllables[word.stressed - 1].stressed = True
+                word.stressed = num_syl - 1
+    word.syllables[word.stressed].stressed = True
     word.stress_found = True
     return word
 
@@ -79,7 +78,6 @@ def return_section(f):
 
 @return_section
 def onset(word: WordProgress):
-
     while not word.ended and word.char in CONSONANTS_BAR_Y:
         word.next()
 
@@ -95,7 +93,7 @@ def onset(word: WordProgress):
 
 
 @return_section
-def nucleus(word: WordProgress):
+def nucleus(word: WordProgress):  # noqa: C901
     start_pos = word.pos
 
     if word.ended:
@@ -148,10 +146,10 @@ def nucleus(word: WordProgress):
 
         # The previous is closed
         if second_vowel.has_accent:
+            word.accent = word.pos
             word.stress_found = True
         word.next()
 
-
     # Closed-vowel with written accent, can't be a triphthong, but could be a diphthong
     elif second_vowel is VowelType.CLOSED_WITH_ACCENT:
         word.accent = word.pos
@@ -188,7 +186,7 @@ def nucleus(word: WordProgress):
 
 
 @return_section
-def coda(word: WordProgress):
+def coda(word: WordProgress):  # noqa: C901
     if word.ended or is_vowel(word.char):
         return  # No coda
 
@@ -232,24 +230,26 @@ def coda(word: WordProgress):
         # else it begins in the letter 'y'
         if c2 == 'y':
             if c1 not in 'slrnc':
-                word.next() # move the pointer to the y
+                word.next()  # move the pointer to the y
             return
 
+        # fmt: off
         if digraph in ('gl', 'kl', 'bl', 'vl', 'pl', 'fl', 'tl',
                        'gr', 'kr', 'br', 'vr', 'pr', 'fr', 'tr', 'dr'):
             return
+        # fmt:on
 
         word.next()
         return
-    else: # 3rd consonant
-        if word.pos >= word.len - 3: # The word ends with 3 consonants
+    else:  # 3rd consonant
+        if word.pos >= word.len - 3:  # The word ends with 3 consonants
             if c2 == 'y' and c1 in 'slrnc':  # y as vowel
                 return
 
             if c3 == 'y':
                 word.next()
             else:
-                word.next(3) # The word ends with 3 consonants
+                word.next(3)  # The word ends with 3 consonants
             return
 
         # This is not the end of the word
@@ -267,8 +267,7 @@ def coda(word: WordProgress):
         # separated and they always begin a new syllable.
         # y as a vowel starts a new syllable
         # ch starts a new syllable
-        if c3 in 'lry' or c1 + c2 == 'ch':
+        if c3 in 'lry' or c2 + c3 == 'ch':
             word.next()  # The next syllable starts in c2
         else:
             word.next(2)  # The next syllable starts in c3
-
